==> haskell-charset-0.3.9-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 charset
version:              0.3.9
visibility:           public
id:                   charset-0.3.9-ioRqRzoxE64eMPDi2vCe9
key:                  charset-0.3.9-ioRqRzoxE64eMPDi2vCe9
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  bf8aa05903adb5c1a046e301f860b3d4
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.0.2/site-local/charset-0.3.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/charset-0.3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.9-ioRqRzoxE64eMPDi2vCe9
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    unordered-containers-0.2.18.0-5g7cvfJKetKCmnCFTnDbJb

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.9-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 charset
version:              0.3.9
visibility:           public
id:                   charset-0.3.9-5fxbufqLTnBK62HCaAWU2e
key:                  charset-0.3.9-5fxbufqLTnBK62HCaAWU2e
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  2bc3399c7309f80ad4e47b795b3a8a8c
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.0.2/site-local/charset-0.3.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/charset-0.3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.9-5fxbufqLTnBK62HCaAWU2e
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    unordered-containers-0.2.18.0-5p1LkGNUihlGGE57L3Yn33

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
